streamStatus property
The current status of the stream being described. The stream status is one of the following states:
-
CREATING- The stream is being created. Kinesis Data Streams immediately returns and setsStreamStatustoCREATING. -
DELETING- The stream is being deleted. The specified stream is in theDELETINGstate until Kinesis Data Streams completes the deletion. -
ACTIVE- The stream exists and is ready for read and write operations or deletion. You should perform read and write operations only on anACTIVEstream. -
UPDATING- Shards in the stream are being merged or split. Read and write operations continue to work while the stream is in theUPDATINGstate.
Implementation
final StreamStatus streamStatus;